Index: trunk/src/org/openstreetmap/josm/actions/downloadtasks/DownloadTaskList.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/downloadtasks/DownloadTaskList.java	(revision 16768)
+++ trunk/src/org/openstreetmap/josm/actions/downloadtasks/DownloadTaskList.java	(revision 16770)
@@ -266,8 +266,7 @@
                                         Utils.joinAsHtmlUnorderedList(items)) + "</html>",
                                 tr("Errors during download"), JOptionPane.ERROR_MESSAGE);
+                        return;
                     }
                 });
-
-                return;
             }
 

Index: trunk/src/org/openstreetmap/josm/actions/UpdateDataAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/UpdateDataAction.java	(revision 16768)
+++ trunk/src/org/openstreetmap/josm/actions/UpdateDataAction.java	(revision 16770)
@@ -86,6 +86,7 @@
 
         if (areasToDownload.isEmpty()) {
-            // no bounds defined in the dataset? we update all primitives in the data set using a series of multi fetch requests
-            UpdateSelectionAction.updatePrimitives(editLayer.data.allPrimitives());
+            // no bounds defined in the dataset? We update all but the incomplete primitives in the data set
+            UpdateSelectionAction.updatePrimitives(editLayer.data.allPrimitives().stream()
+                    .filter(p -> !p.isNew() && !p.isIncomplete()).collect(Collectors.toList()));
         } else {
             // bounds defined? => use the bbox downloader